#ifndef JOB_GENERATEPLAYLIST_H
#define JOB_GENERATEPLAYLIST_H

#include "prokyon.h"
#include "jobbase.h"

class Job_GeneratePlaylist : public JobBase  {
public:
	Job_GeneratePlaylist(int _numberTracks, int _minTrackLength, int _maxTrackLength, bool _onlyFavouriteArtists, bool _onlyHarddisk, int _minRating);

    int type() { return JOB_GENERATE_PLAYLIST; }

	void run();
		
	~Job_GeneratePlaylist();

private:
	int numberTracks;
	int minTrackLength;
	int maxTrackLength;
    bool onlyFavouriteArtists;
    bool onlyHarddisk;
    int minRating;
};

#endif
